---
title: 정기결제의 인증 과정 필수 여부
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 정기결제
seo:
  title: 정기결제의 인증 과정 필수 여부
  description: >-
    PG사의 정기결제 서비스에 본인인증 및 공인인증 단계가 포함되어있는 경우를 안내해 드립니다. PG사 별로 본인인증을 요구하는 방법과
    조건은 상이할 수 있습니다.
  keywords:
    - 정기결제
tags:
  - 정기결제
pgCompanies:
  - 나이스페이먼츠
  - 다날
  - 토스페이먼츠
  - KICC
  - NHN KCP
  - KG이니시스
searchTags:
  - 비인증
  - 공인인증
  - 인증필수
  - 정기결제 인증
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="정기결제는 빌링키를 발급받는 단계에서 아래 2가지로 분류됩니다." />

### **빌링키 발급 방식에 따른 인증과정 구분**

1. **PG사의 결제창을 띄우는 방식**

<Indent level="1">

- PG사의 결제창 안에서 '공인인증(본인인증)' 절차를 요구하게 됩니다

</Indent>

**2. API 호출 방식**

<Indent level="1">

- API 호출만으로 빌링키 발급이 가능하기 때문에 인증 절차가 없습니다.

</Indent>

<Callout title="정기결제 연동방식 보러가기 ↗" />

### **결제대행사별 인증과정 포함 여부**

- **KG이니시스**

<Indent level="1">

- PC환경에서는 공인인증을 필수로 요구하나, 모바일 환경에서는 생략됩니다.

</Indent>

- **KCP**

<Indent level="1">

- 공인인증 생략이 기본값이나, 내부 설정 및 입점 기준 등 PG사 정책에 따라 공인인증 과정이 포함될 수 있습니다.

</Indent>

- **KICC**

<Indent level="1">

- 정기결제 시 별도의 추가 인증 절차는 거치지 않고 있습니다.

</Indent>

- **다날**

<Indent level="1">

- 정기결제시 본인인증 절차를 생략하고자 하실 경우 다날측으로 요청하시어 설정하실 수 있습니다. \
  신규계약시 다날측으로 본인인증이 생략되도록 소통해주시거나,\
  이미 사용중이실 경우 아래 문의처를 통해 본인인증절차 생략을 문의해주시기 바랍니다!
- 다날 문의처
  - 1566-3355 (고객센터)
  - 031-697-1280 (포트원 계약 담당부서)

</Indent>

- **토스페이먼츠**

<Indent level="1">

- 본인인증 절차를 생략하기 위해서는 토스페이먼츠 측을 통해 요청을 주셔야 하나, 토스페이먼츠 내부 심사를 통해 생략 가능 여부가 확정되오니 참고 부탁드립니다.

</Indent>

- **나이스페이먼츠 (신모듈)**

<Indent level="1">

- 결제창 방식은 PC/모바일 상관없이 빌링키 발급 시 본인인증 절차가 필수입니다.

</Indent>

- 한국결제네트웍스(KPN)

<Indent level="1">

- API 연동방식 진행 시  본인인증 절차는 별도로 진행 해주셔야 하오니 참고 부탁드립니다.

</Indent>
